﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace TechNote74_SmartMessageBox_CS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // timer를 사용하는 경우 사용할 카운트값. 기본값 10
        private int m_iEndCount;

        private void Form1_Load(object sender, EventArgs e)
        {
            // 현재 Form을 MainForm으로 설정합니다.
            smartForm1.MainForm = this;

            // SmartMessageBox의 Size 설정
            SmartX.SmartMessageBox.Size(500, 250);
            // SmartMessageBox가 다른 컴포넌트에 가려지지 않도록 최상단에 보여지도록 설정
            SmartX.SmartMessageBox.TopMost = true;
            // SmartMessageBox를 NoneBlocking 방식으로 사용하기 위한 설정.
            SmartX.SmartMessageBox.OwnerHandle = this.Handle;
            // SmartMessageBox를 NoneBlocking 방식으로 Show된 후 Close될 때 발생하는 이벤트를 추가
            SmartX.SmartMessageBox.OnNoneBlockingDialogClosing += new SmartX.SmartMessageBox.DialogCloseEventHandler(SmartMessageBox_OnNoneBlockingDialogClosing);

            // 멤버 변수 초기화
            m_iEndCount = 10;
        }

        // SmartMessageBox 종료 시간 설정
        private void btnTimeSet_Click(object sender, EventArgs e)
        {
            smartTimer1.CounterMode = SmartX.SmartTimer.CounterModes.Down_Counter;

            // SmartTimer의 TimeCount 설정
            smartTimer1.TimeCount = ((long)udEndTimeSet.Value * (long)1000);

            // 각 Timer의 Interval 설정. (1000 = 1Sec)
            smartTimer1.Interval = 1000;
            timer1.Interval = 1000;
        }

        // SmartMessageBox를 NoneBlocking 방식으로 Show하는 Click 이벤트
        private void ShowSmartMessageBox_Click(object sender, EventArgs e)
        {
            // SmartMessageBox의 Caption, Message, Button에 출력할 초기 텍스트를 저장
            string strSetTime = udEndTimeSet.Value.ToString();

            // Timer Count 설정
            m_iEndCount = Convert.ToInt32(udEndTimeSet.Value);

            // SmartMessageBox를 NoneBlocking 방식으로 Show
            SmartX.SmartMessageBox.Show_NoneBlocking(strSetTime + "초 후 자동으로 닫히는 메시지박스 입니다.", strSetTime + "초 후 닫힙니다.", strSetTime, strSetTime, strSetTime, SmartX.CMsgBoxIcon.Hand);

            // 선택한 버튼이 "SmartTimer사용"인 경우
            if (sender == btnSmartTimer)
            {
                smartTimer1.Start();
            }
            // 선택한 버튼이 "Timer사용"인 경우
            else
            {
                timer1.Enabled = true;
            }
        }

        // SmartMessageBox가 Close될 때 발생하는 이벤트. (dResult : SmartMessageBox에서 선택한 버튼)
        private void SmartMessageBox_OnNoneBlockingDialogClosing(SmartX.CDialogResult dResult)
        {
            // SmartTimer, Timer를 정지합니다.
            if (smartTimer1.IsStart == true)
            {
                smartTimer1.Stop();
            }
            else
            {
                timer1.Enabled = false;
                // 카운트를 초기화합니다.
                m_iEndCount = Convert.ToInt32(udEndTimeSet.Value);
            }
        }

        // SmartTimer를 이용하여 SmartMessageBox의 Text를 변경하는 Tick 이벤트
        private void smartTimer1_Tick(object sender, EventArgs e)
        {
            // SmartTimer의 현재 시간의 초(Sec)값을 가져옵니다.
            long lNowTime = smartTimer1.GetNowTimeFormat(SmartX.SmartTimer.TimeConvertFormatTypes.Minute_Second).dwSec;

            // SmartTimer의 현재 시간의 밀리초(ms)값을 가져옵니다.
            long lNowTimeMilli = smartTimer1.GetNowTimeFormat(SmartX.SmartTimer.TimeConvertFormatTypes.Minute_Second).dwMillisecond;

            // 현재 시간이 만약 8sec 900ms 인 경우, 즉 시간을 내림하여 체크하는 경우를 방지하기 위해
            // 현재 ms가 500을 초과하는 경우 현재 Sec를 1초 더합니다.
            if (lNowTimeMilli > 500)
            {
                lNowTime += 1;
            }

            // 카운트가 0이되면 메시지박스를 Closing
            if (lNowTime <= 0)
            {
                // SmartMessageBox를 Closing하는 메서드
                SmartX.SmartMessageBox.Close_NoneBlocking();
            }
            else
            {
                string strTime = lNowTime.ToString("00");
                // 버튼의 텍스트를 변경
                SmartX.SmartMessageBox.SetButsText_NoneBlocking(strTime, strTime, strTime);

                // 캡션의 텍스트를 변경
                SmartX.SmartMessageBox.SetCaption_NoneBlocking(strTime + "초 후 닫힙니다.");

                // 메시지의 텍스트를 변경
                SmartX.SmartMessageBox.SetMessage_NoneBlocking(strTime + "초 후 자동으로 닫히는 메시지박스 입니다.");
            }
        }

        // SmartTimer의 시간이 EndTime이 될 때 발생하는 이벤트.
        private void smartTimer1_OnFinishTick(object sender, EventArgs e)
        {
            // SmartMessageBox를 Closing하는 메서드
            SmartX.SmartMessageBox.Close_NoneBlocking();
        }

        // Timer를 이용하여 SmartMessageBox의 Text를 변경하는 Tick 이벤트
        private void timer1_Tick(object sender, EventArgs e)
        {
            // 변수를 이용하는 방법.
            // 이 방법은 백그라운드 작업에 따라 시간이 지연될 수 있습니다.
            if (--m_iEndCount <= 0)
            {
                // SmartMessageBox를 Closing하는 메서드
                SmartX.SmartMessageBox.Close_NoneBlocking();
            }
            else
            {
                // 버튼의 텍스트를 변경
                SmartX.SmartMessageBox.SetButsText_NoneBlocking(m_iEndCount.ToString(), m_iEndCount.ToString(), m_iEndCount.ToString());

                // 캡션의 텍스트를 변경
                SmartX.SmartMessageBox.SetCaption_NoneBlocking(m_iEndCount.ToString() + " 초후 닫힙니다.");

                // 메시지의 텍스트를 변경
                SmartX.SmartMessageBox.SetMessage_NoneBlocking(m_iEndCount.ToString() + " 초 후 자동으로 닫히는 메시지박스 입니다.");
            }
        }

        // CPU 사용량을 증가시키기 위한 Timer를 Start하는 메서드
        private void btnDrawStart_Click(object sender, EventArgs e)
        {
            // SmartTimer1의 Interval 값을 줄이면 더 정확한 시간을 체크할 수 있습니다.
            // 기본 설정값 : smartTimer1.Interval = 1000;

            // 부하 시작
            smartTimer2.Start();
        }

        // SmartDraw를 For문을 사용해 여러 도형을 랜덤으로 그리게 하여 CPU 사용량을 증가시킵니다.
        private void smartTimer2_Tick(object sender, EventArgs e)
        {
            smartTimer2.Stop();
            // 랜덤변수 생성
            Random rdVal = new Random();
            Random rdRepeat = new Random();
            int iRand = rdRepeat.Next(0, 5);

            // 도형의 크기설정을 위한 변수
            int iWidth, iHeight, iTop, iLeft;
            smartDraw1.SetBrushStyle(Color.Black);

            // Draw할 도형을 랜덤으로 선택
            // 각 도형은 For문을 사용하여 500번씩 반복하여 Draw합니다.
            switch (iRand)
            {
                case 0:
                    for (int i = 0; i < 500; i++)
                    {
                        smartDraw1.SetPenStyle(Color.FromArgb(rdVal.Next(0xffffff)), 1);
                        smartDraw1.Line(rdVal.Next(10, 720), rdVal.Next(10, 360), rdVal.Next(10, 720), rdVal.Next(10, 360));
                        Application.DoEvents();
                    }
                    break;
                case 1:
                    for (int i = 0; i < 500; i++)
                    {
                        iTop = rdVal.Next(10, 350);
                        iLeft = rdVal.Next(10, 710);
                        iWidth = rdVal.Next(0, (710 - iLeft));
                        iHeight = rdVal.Next(0, (350 - iTop));

                        smartDraw1.SetBrushStyle(Color.FromArgb(rdVal.Next(0xffffff)));
                        smartDraw1.SetPenStyle(Color.FromArgb(rdVal.Next(0xffffff)), 1);
                        smartDraw1.Rectangle(iLeft, iTop, iWidth, iHeight);
                        Application.DoEvents();
                    }
                    break;
                case 2:                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     
                    for (int i = 0; i < 500; i++)
                    {
                        iTop = rdVal.Next(10, 350);
                        iLeft = rdVal.Next(10, 710);
                        iWidth = rdVal.Next(0, (710 - iLeft));
                        iHeight = rdVal.Next(0, (350 - iTop));

                        smartDraw1.SetBrushStyle(Color.FromArgb(rdVal.Next(0xffffff)));
                        smartDraw1.SetPenStyle(Color.FromArgb(rdVal.Next(0xffffff)), 1);
                        smartDraw1.RoundRect(iLeft, iTop, iWidth, iHeight, rdVal.Next(30));
                        Application.DoEvents();
                    }
                    break;
                case 3:
                    for (int i = 0; i < 500; i++)
                    {
                        smartDraw1.SetBrushStyle(Color.FromArgb(rdVal.Next(0xffffff)));
                        smartDraw1.SetPenStyle(Color.FromArgb(rdVal.Next(0xffffff)), 1);
                        smartDraw1.Circle(rdVal.Next(710), rdVal.Next(350), rdVal.Next(100));
                        Application.DoEvents();
                    }
                    break;
                case 4:
                    for (int i = 0; i < 500; i++)
                    {
                        smartDraw1.SetBrushStyle(Color.FromArgb(rdVal.Next(0xffffff)));
                        smartDraw1.SetPenStyle(Color.FromArgb(rdVal.Next(0xffffff)), 1);
                        smartDraw1.Ellipse(rdVal.Next(710), rdVal.Next(350), rdVal.Next(100), rdVal.Next(100));
                        Application.DoEvents();
                    }
                    break;
                case 5:
                    Point[] points = new Point[10];
                    int iSize, iXOffset, iYOffset;

                    for (int i = 0; i < 500; i++)
                    {
                        iSize = rdVal.Next(5);
                        iXOffset = rdVal.Next(700);
                        iYOffset = rdVal.Next(350);

                        smartDraw1.SetBrushStyle(Color.FromArgb(rdVal.Next(0xffffff)));
                        smartDraw1.SetPenStyle(Color.FromArgb(rdVal.Next(0xffffff)), 1);

                        points[0].X = (16 * iSize) + iXOffset;
                        points[0].Y = (28 * iSize) + iYOffset;
                        points[1].X = (19 * iSize) + iXOffset;
                        points[1].Y = (17 * iSize) + iYOffset;
                        points[2].X = (30 * iSize) + iXOffset;
                        points[2].Y = (17 * iSize) + iYOffset;
                        points[3].X = (21 * iSize) + iXOffset;
                        points[3].Y = (11 * iSize) + iYOffset;
                        points[4].X = (25 * iSize) + iXOffset;
                        points[4].Y = (1 * iSize) + iYOffset;
                        points[5].X = (16 * iSize) + iXOffset;
                        points[5].Y = (7 * iSize) + iYOffset;
                        points[6].X = (7 * iSize) + iXOffset;
                        points[6].Y = (1 * iSize) + iYOffset;
                        points[7].X = (11 * iSize) + iXOffset;
                        points[7].Y = (11 * iSize) + iYOffset;
                        points[8].X = (2 * iSize) + iXOffset;
                        points[8].Y = (17 * iSize) + iYOffset;
                        points[9].X = (13 * iSize) + iXOffset;
                        points[9].Y = (17 * iSize) + iYOffset;

                        smartDraw1.Polygon(points);
                        Application.DoEvents();
                    }
                    break;
            }
            smartTimer2.Start();
        }

        // "부하중지" 버튼 클릭 시 발생
        private void btnDrawStop_Click(object sender, EventArgs e)
        {
            smartTimer2.Stop();
        }


        // 프로그램을 종료할 때 Timer들이 Stard
        private void Form1_Closing(object sender, CancelEventArgs e)
        {
            if (smartTimer1.IsStart == true) smartTimer1.Stop();
            if (smartTimer2.IsStart == true) smartTimer2.Stop();
            if (timer1.Enabled == true) timer1.Enabled = false;
        }
    }
}